@@ -71,9 +71,10 @@ count2prob <- function(x, type=3){
   stopifnot(is.matrix(x))
   stopifnot(any(!is.na(x)))
   stopifnot(type %in% 1:6)
-  stopifnot(rowSums(x) %% 1 == 0)
+  is.wholenumber <- function(x,tol=.Machine$double.eps**0.5) abs(x - round(x)) < tol
+  stopifnot(is.wholenumber(rowSums(x)))
 
-  if (all(rowSums(x) == 1)){
+  if (isTRUE(all.equal(rowSums(x), rep(1, nrow(x))))){
     xout <- x
   } else {
     ## select parameters to determine plotting position
